searchData={"items":[{"type":"module","title":"Turboprop","doc":"A toolkit to build beautiful, accessible components for Phoenix using Tailwind and Zag.","ref":"Turboprop.html"},{"type":"module","title":"Parts - Turboprop","doc":"Turboprop consists of multiple parts, each with their own purpose in building your component library.","ref":"Turboprop.html#module-parts"},{"type":"module","title":"Turboprop Hooks - Turboprop","doc":"Turboprop Hooks allow you add a ton of accessibility features to your components by simply adding a hook and a few data attributes to them.  \nThis includes:\n\n- Keyboard interactions\n- Focus management\n- ARIA attributes\n\nYou can either install and use them through the hex.pm dependency and some helpers we offer to add the relevant attributes to a component,\nor install them directly through npm and adding the attributes yourself.  \n\nAs an example, this renders a fully accessible dropdown menu:\n\n```heex\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       Anchor \n     \n   \n \n \n```","ref":"Turboprop.html#module-turboprop-hooks"},{"type":"module","title":"Turboprop Merge - Turboprop","doc":"Turboprop Merge allows you to easily merge a list of Tailwind Classes to avoid style conflicts.\n\nImagine this component:\n\n```elixir\nattr :class, :string, doc: \"Class override\"\ndef button(assigns) do\n  ~H\"\"\"\n   Click me! \n  \"\"\"\nend\n```\n\nAnd imagine wanting to make the text a little bigger as a one-off. You've already added a `@class` attribute, but rendering the component\nwith `class=\"text-lg\"` will lead to an HTML output of `\"bg-black px-3 py-1.5 text-sm text-lg\"`, with two competing font size classes.\n\nNow, replace the `class` attribute with `class={merge([\"bg-black px-3 py-1.5 text-sm\", @class])}` and you will magically get\n`\"bg-black px-3 py-1.5 text-lg\"`.\n\n#### Prior art\n\nThis type of library exists in the JavaScript world already, in multiple flavors. Turboprop Merge was heavily inspired especially by\n[tailwind-merge](https://www.npmjs.com/package/tailwind-merge), so much so that we copied their tests as a starting point.","ref":"Turboprop.html#module-turboprop-merge"},{"type":"module","title":"Turboprop.Hooks","doc":"Turboprop Hooks offer an easy way to build accessible components.  \n\nYou can easily add features like keyboard interaction, focus management and ARIA attributes to your component.  \nTurboprop Hooks are built around the state machines of [Zag](https://zagjs.com) and offer the same rules as them. You will find a link to\neach state machine's documentation in the hook's module.","ref":"Turboprop.Hooks.html"},{"type":"module","title":"Installation - Turboprop.Hooks","doc":"The JavaScript side of the hooks are available as an npm package,\n[`@leuchtturm/turboprop`](https://npmjs.com/package/@leuchtturm/turboprop). Add it to your assets by running `npm i --save-exact\n@leuchtturm/turboprop` or the equivalent for the package manager you are using. Then, import the hooks and add them to your LiveView\nconfiguration as follows:\n\n```javascript\nimport { Hooks } from \"@leuchtturm/turboprop\";\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    ...Hooks\n  },\n});\n```\n\nThat's it!","ref":"Turboprop.Hooks.html#module-installation"},{"type":"module","title":"Anatomy - Turboprop.Hooks","doc":"Each hook comes with a wrapper that adds the `phx-hook` directive and a bunch of `data` attributes that specify which role each element\nhas. Revisiting the dropdown menu example from the [Turboprop](`m:Turboprop`) documentation, the expanded elements look like this:\n\n```html\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       \n        Anchor\n       \n     \n   \n \n```\nFor the `Menu` hook, the required parts are `trigger`, `positioner`, `content`, and `item`. In addition to that, it can also be configured\nwith optional parts like `separator` and `group`. Each hook's module will list both required and optional fields and how they relate to\neach other with nesting.  \nMost hooks only need the `data-part` attributes set, but some also have callbacks to the server where an event is required. Check the\ndocumentation for each hook.","ref":"Turboprop.Hooks.html#module-anatomy"},{"type":"function","title":"Turboprop.Hooks.id/0","doc":"","ref":"Turboprop.Hooks.html#id/0"},{"type":"module","title":"Turboprop.Hooks.Menu","doc":"An accessible dropdown and context menu that is used to display a list of actions or options that a user can choose.\n\nWrapper around [Zag's Menu state machine](https://github.com/chakra-ui/zag/tree/main/packages/machines/menu).","ref":"Turboprop.Hooks.Menu.html"},{"type":"module","title":"Required parts - Turboprop.Hooks.Menu","doc":"- `menu` - Root element owning the hook.\n- `menu_trigger` - Element opening the hook.\n- `menu_positioner` - Element positioning the element in the viewport.\n- `menu_content` - Wrapper element around the items.\n- `menu_item` - Selectable item in the menu.","ref":"Turboprop.Hooks.Menu.html#module-required-parts"},{"type":"module","title":"Optional parts - Turboprop.Hooks.Menu","doc":"- `menu_item_group` - Wrapper around a group of items.\n- `menu_item_group_label` - Label for a group of items.\n- `menu_separator` - Separator between two groups of items.","ref":"Turboprop.Hooks.Menu.html#module-optional-parts"},{"type":"module","title":"Item Groups - Turboprop.Hooks.Menu","doc":"When grouping items, groups can be labeled. To give the group element label, it requires a `name` attribute with the corresponding label\nhaving a `data-for` attribute set. The example below shows this.","ref":"Turboprop.Hooks.Menu.html#module-item-groups"},{"type":"module","title":"Example - Turboprop.Hooks.Menu","doc":"```heex\n \n   \n    Menu\n   \n   \n     \n      <.link navigate=\"/dashboard\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n        Dashboard\n      </.link>\n       \n       Account \n       \n        <.link navigate=\"/signup\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Sign up\n        </.link>\n        <.link navigate=\"/login\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Login\n        </.link>\n       \n     \n   \n \n```","ref":"Turboprop.Hooks.Menu.html#module-example"},{"type":"function","title":"Turboprop.Hooks.Menu.menu/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_content/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu_content/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu_item/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu_item_group/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group_label/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu_item_group_label/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_positioner/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu_positioner/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_separator/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu_separator/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_trigger/0","doc":"","ref":"Turboprop.Hooks.Menu.html#menu_trigger/0"},{"type":"module","title":"Turboprop.Merge","doc":"Utilities for joining and merging Tailwind classes.","ref":"Turboprop.Merge.html"},{"type":"function","title":"Turboprop.Merge.join/1","doc":"Joins a list of classes.","ref":"Turboprop.Merge.html#join/1"},{"type":"function","title":"Turboprop.Merge.merge/2","doc":"Joins and merges a list of classes.","ref":"Turboprop.Merge.html#merge/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}